pub struct SyntaxVerifier;Expand description
Verify that a Rust source file has valid syntax.
Uses the syn crate to parse the file as a Rust source file.
Analogous to SyntaxVerifier in Python (which uses ast.parse)
and TypeScript (which does a basic readability check).